@@ -2,9 +2,9 @@ var indexSectionsWithContent =
 {
   0: "abcdefghijklmnoprstuwxy",
   1: "j",
-  2: "cdemprst",
+  2: "cdegmprst",
   3: "jo",
-  4: "abcdefghilmnoprstuwxy",
+  4: "abcdefghijlmnoprstuwxy",
   5: "j",
   6: "j",
   7: "jk",
